@@ -1,7 +1,8 @@
 # gctorture()
 
 # Tests of DSE curvature functions from dsecurvature.function.testsA
- require("dse2"); require("curve") #,  warn.conflicts=FALSE)
+if(!require("dse2"))  stop("this test requires dse2.")
+if(!require("curve"))stop("this test requires curve.")
  Sys.info()
  version.dse()
  
@@ -56,7 +57,7 @@ cat("DSE curvature test A 6b...\n")
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.large < error) 
      {if (any(is.na(error)))  cat("contains na's: ",  is.na(error),  "\n")
       if (any(is.nan(error))) cat("contains nan's: ", is.nan(error), "\n")
-      print.test.value(c(tst), digits=18)
+      printTestValue(c(tst), digits=18)
       all.ok <- F  
      }
 
@@ -71,7 +72,7 @@ cat("DSE curvature test A 6a...\n")
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.large < error) 
      {if (any(is.na(error)))  cat("contains na's: ",  is.na(error),  "\n")
       if (any(is.nan(error))) cat("contains nan's: ", is.nan(error), "\n")
-      print.test.value(c(tst), digits=18)
+      printTestValue(c(tst), digits=18)
       all.ok <- F  
      }
 
