@@ -1,5 +1,6 @@
 # Tests of DSE curvature functions from dsecurvature.function.testsA
- require("dse2"); require("curve") #,  warn.conflicts=FALSE)
+if(!require("dse2"))  stop("this test requires dse2.")
+if(!require("curve"))stop("this test requires curve.")
  Sys.info()
  version.dse()
  
@@ -18,13 +19,13 @@ test.rng <- list(kind="Wichmann-Hill",seed=c(979,1479,1542),normal.kind="Box-Mul
   
 # from user guide
 
-  VARmodel<-ARMA(A=array(c(1,.5,.3,0,.2,.1,0,.2,.05,1,.5,.3),c(3,2,2)),
+  ARMAmodel1<-ARMA(A=array(c(1,.5,.3,0,.2,.1,0,.2,.05,1,.5,.3),c(3,2,2)),
              B=array(c(1,.2,0,.1,0,0,1,.3),c(2,2,2)), C=NULL) 
 
-# Note this gives a terrible fit.
-  VARmodel<-l(VARmodel,simulate(VARmodel, rng=test.rng))
-  SSmodel  <- l(to.SS(VARmodel),  VARmodel$data)
-  ARMAmodel<- l(to.ARMA(SSmodel), VARmodel$data)
+
+  ARMAmodel1<-l(ARMAmodel1,simulate(ARMAmodel1, rng=test.rng))
+  SSmodel  <- l(to.SS(ARMAmodel1),  ARMAmodel1$data)
+  ARMAmodel<- l(to.ARMA(SSmodel), ARMAmodel1$data)
 
 
 #  if(is.Splus()) good <-  c(
@@ -71,7 +72,7 @@ cat("DSE curvature test A 9a...\n")
    cat("max. error ", max(error))
     
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.large < error) 
-     {print.test.value(c(spanSS), digits=18); all.ok <- F }
+     {printTestValue(c(spanSS), digits=18); all.ok <- F }
 
 cat("DSE curvature test A 9b...\n")
 
@@ -80,6 +81,6 @@ cat("DSE curvature test A 9b...\n")
    cat("max. error ", max(error))
     
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.large < error) 
-     {print.test.value(c(spanSS), digits=18); all.ok <- F }
+     {printTestValue(c(spanSS), digits=18); all.ok <- F }
 
   if (! all.ok) stop("some tests FAILED")
