@@ -1,5 +1,6 @@
 # Tests of DSE curvature functions from dsecurvature.function.testsA
- require("dse2"); require("curve") #,  warn.conflicts=FALSE)
+if(!require("dse2"))  stop("this test requires dse2.")
+if(!require("curve"))stop("this test requires curve.")
  Sys.info()
  version.dse()
  
@@ -19,20 +20,20 @@ test.rng <- list(kind="Wichmann-Hill",seed=c(979,1479,1542),normal.kind="Box-Mul
 
 # from user guide
 
-  VARmodel<-ARMA(A=array(c(1,.5,.3,0,.2,.1,0,.2,.05,1,.5,.3),c(3,2,2)),
+  ARMAmodel1<-ARMA(A=array(c(1,.5,.3,0,.2,.1,0,.2,.05,1,.5,.3),c(3,2,2)),
              B=array(c(1,.2,0,.1,0,0,1,.3),c(2,2,2)), C=NULL) 
 
-# Note this gives a terrible fit.
-  VARmodel<-l(VARmodel,simulate(VARmodel, rng=test.rng))
-  SSmodel  <- l(to.SS(VARmodel),  VARmodel$data)
-  ARMAmodel<- l(to.ARMA(SSmodel), VARmodel$data)
-  ARMAmodel.fixed <- l(fix.constants(ARMAmodel), VARmodel$data)
+
+  ARMAmodel1<-l(ARMAmodel1,simulate(ARMAmodel1, rng=test.rng))
+  SSmodel  <- l(to.SS(ARMAmodel1),  ARMAmodel1$data)
+  ARMAmodel<- l(to.ARMA(SSmodel), ARMAmodel1$data)
+  ARMAmodel.fixed <- l(fix.constants(ARMAmodel), ARMAmodel1$data)
   
 cat("DSE curvature test A 11a..")
   #  following test values have all been set using 
   #    R0.63.3pre and gnu f77 on SunOS 5.6 (Solaris)
   #  and reset as of R 1.0.0 
-  hess <- hessian(VARmodel)  
+  hess <- hessian(ARMAmodel1)  
 
 # 1472.1174
    good <- 1397.19588043396584
@@ -41,7 +42,7 @@ cat("DSE curvature test A 11a..")
    cat("max. error ", max(error))
      
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.very.large < error) 
-     {print.test.value(c(tst), digits=18); all.ok <- F }
+     {printTestValue(c(tst), digits=18); all.ok <- F }
 
 cat("DSE curvature test A 11b..")
   hess <- hessian(SSmodel)
@@ -52,7 +53,7 @@ cat("DSE curvature test A 11b..")
    cat("max. error ", max(error))
      
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.very.large < error) 
-     {print.test.value(c(tst), digits=18); all.ok <- F }
+     {printTestValue(c(tst), digits=18); all.ok <- F }
  
 cat("DSE curvature test A 11c..")
   hess <- hessian(ARMAmodel) 
@@ -67,14 +68,18 @@ cat("DSE curvature test A 11c..")
  
 cat("DSE curvature test A 11d..")
   hess <- hessian(ARMAmodel.fixed)
-  # 3038.56
+#  3039.23996170283772   using svd until R 1.6.1 (both Linux and Soaris, but large tolerance)
+#  3039.22741633394708  # R 1.6.1 La.svd with Solaris
+#  3039.24495763039704  # R 1.6.1 La.svd with Mandrake 9.0
+
+good <- if (Sys.info()[["sysname"]] == "Linux")
+               3039.24495763039704 else 3039.22741633394708
 
-   good <- 3039.23996170283772
    tst  <- sum(hess)
    error <- max(abs(good-tst))
    cat("max. error ", max(error))
      
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.very.large < error) 
-     {print.test.value(c(tst), digits=18); all.ok <- F }
+     {printTestValue(c(tst), digits=18); all.ok <- F }
 
   if (! all.ok) stop("some tests FAILED")
